@@ -735,7 +735,7 @@ class CustomActivity(BaseActivity):
     def __init__(self, name: Optional[str], *, emoji: Optional[PartialEmoji] = None, **extra: Any) -> None:
         super().__init__(**extra)
         self.name: Optional[str] = name
-        self.state: Optional[str] = extra.pop('state', None)
+        self.state: Optional[str] = extra.pop('state', name)
         if self.name == 'Custom Status':
             self.name = self.state
 
