@@ -67,6 +67,7 @@ __all__ = (
     'AutoModRuleEventType',
     'AutoModRuleActionType',
     'ForumLayoutType',
+    'ForumOrderType',
 )
 
 if TYPE_CHECKING:
@@ -294,6 +295,7 @@ class DefaultAvatar(Enum):
     green = 2
     orange = 3
     red = 4
+    pink = 5
 
     def __str__(self) -> str:
         return self.name
@@ -751,6 +753,11 @@ class ForumLayoutType(Enum):
     gallery_view = 2
 
 
+class ForumOrderType(Enum):
+    latest_activity = 0
+    creation_date = 1
+
+
 def create_unknown_value(cls: Type[E], val: Any) -> E:
     value_cls = cls._enum_value_cls_  # type: ignore # This is narrowed below
     name = f'unknown_{val}'
