@@ -175,7 +175,13 @@ class Parameter(inspect.Parameter):
         if self._displayed_default is not empty:
             return self._displayed_default
 
-        return None if self.required else str(self.default)
+        if self.required:
+            return None
+
+        if callable(self.default) or self.default is None:
+            return None
+
+        return str(self.default)
 
     @property
     def displayed_name(self) -> Optional[str]:
@@ -300,6 +306,7 @@ CurrentGuild = parameter(
     displayed_default='<this server>',
     converter=GuildConverter,
 )
+CurrentGuild._fallback = True
 
 
 class Signature(inspect.Signature):
