@@ -619,7 +619,7 @@ class Loop(Generic[LF]):
         if not inspect.iscoroutinefunction(coro):
             raise TypeError(f'Expected coroutine function, received {coro.__class__.__name__}.')
 
-        self._error = coro
+        self._error = coro  # type: ignore
         return coro
 
     def _get_next_sleep_time(self, now: datetime.datetime = MISSING) -> datetime.datetime:
