@@ -119,6 +119,12 @@ class Permissions(BaseFlags):
                to be, for example, constructed as a dict or a list of pairs.
                Note that aliases are not shown.
 
+        .. describe:: bool(b)
+
+            Returns whether the permissions object has any permissions set to ``True``.
+
+            .. versionadded:: 2.0
+
     Attributes
     -----------
     value: :class:`int`
@@ -177,7 +183,7 @@ class Permissions(BaseFlags):
         """A factory method that creates a :class:`Permissions` with all
         permissions set to ``True``.
         """
-        return cls(0b11111111111111111111111111111111111111111)
+        return cls(0b11111111111111111111111111111111111111111111111)
 
     @classmethod
     def _timeout_mask(cls) -> int:
@@ -192,6 +198,10 @@ class Permissions(BaseFlags):
         base.read_messages = True
         base.send_tts_messages = False
         base.manage_messages = False
+        base.create_private_threads = False
+        base.create_public_threads = False
+        base.manage_threads = False
+        base.send_messages_in_threads = False
         return base
 
     @classmethod
@@ -200,7 +210,7 @@ class Permissions(BaseFlags):
         ``True`` and the guild-specific ones set to ``False``. The guild-specific
         permissions are currently:
 
-        - :attr:`manage_emojis`
+        - :attr:`manage_expressions`
         - :attr:`view_audit_log`
         - :attr:`view_guild_insights`
         - :attr:`manage_guild`
@@ -209,6 +219,7 @@ class Permissions(BaseFlags):
         - :attr:`kick_members`
         - :attr:`ban_members`
         - :attr:`administrator`
+        - :attr:`create_expressions`
 
         .. versionchanged:: 1.7
            Added :attr:`stream`, :attr:`priority_speaker` and :attr:`use_application_commands` permissions.
@@ -217,8 +228,11 @@ class Permissions(BaseFlags):
            Added :attr:`create_public_threads`, :attr:`create_private_threads`, :attr:`manage_threads`,
            :attr:`use_external_stickers`, :attr:`send_messages_in_threads` and
            :attr:`request_to_speak` permissions.
+
+        .. versionchanged:: 2.3
+           Added :attr:`use_soundboard`, :attr:`create_expressions` permissions.
         """
-        return cls(0b111110110110011111101111111111101010001)
+        return cls(0b01000111110110110011111101111111111101010001)
 
     @classmethod
     def general(cls) -> Self:
@@ -230,8 +244,11 @@ class Permissions(BaseFlags):
            permissions :attr:`administrator`, :attr:`create_instant_invite`, :attr:`kick_members`,
            :attr:`ban_members`, :attr:`change_nickname` and :attr:`manage_nicknames` are
            no longer part of the general permissions.
+
+        .. versionchanged:: 2.3
+            Added :attr:`create_expressions` permission.
         """
-        return cls(0b01110000000010000000010010110000)
+        return cls(0b10000000000001110000000010000000010010110000)
 
     @classmethod
     def membership(cls) -> Self:
@@ -254,14 +271,17 @@ class Permissions(BaseFlags):
         .. versionchanged:: 2.0
            Added :attr:`create_public_threads`, :attr:`create_private_threads`, :attr:`manage_threads`,
            :attr:`send_messages_in_threads` and :attr:`use_external_stickers` permissions.
+
+        .. versionchanged:: 2.3
+            Added :attr:`send_voice_messages` permission.
         """
-        return cls(0b111110010000000000001111111100001000000)
+        return cls(0b10000000111110010000000000001111111100001000000)
 
     @classmethod
     def voice(cls) -> Self:
         """A factory method that creates a :class:`Permissions` with all
         "Voice" permissions from the official Discord UI set to ``True``."""
-        return cls(0b1000000000000011111100000000001100000000)
+        return cls(0b1001001000000000000011111100000000001100000000)
 
     @classmethod
     def stage(cls) -> Self:
@@ -301,7 +321,7 @@ class Permissions(BaseFlags):
         - :attr:`manage_messages`
         - :attr:`manage_roles`
         - :attr:`manage_webhooks`
-        - :attr:`manage_emojis_and_stickers`
+        - :attr:`manage_expressions`
         - :attr:`manage_threads`
         - :attr:`moderate_members`
 
@@ -540,13 +560,21 @@ class Permissions(BaseFlags):
         return 1 << 29
 
     @flag_value
-    def manage_emojis(self) -> int:
-        """:class:`bool`: Returns ``True`` if a user can create, edit, or delete emojis."""
+    def manage_expressions(self) -> int:
+        """:class:`bool`: Returns ``True`` if a user can edit or delete emojis, stickers, and soundboard sounds.
+
+        .. versionadded:: 2.3
+        """
         return 1 << 30
 
-    @make_permission_alias('manage_emojis')
+    @make_permission_alias('manage_expressions')
+    def manage_emojis(self) -> int:
+        """:class:`bool`: An alias for :attr:`manage_expressions`."""
+        return 1 << 30
+
+    @make_permission_alias('manage_expressions')
     def manage_emojis_and_stickers(self) -> int:
-        """:class:`bool`: An alias for :attr:`manage_emojis`.
+        """:class:`bool`: An alias for :attr:`manage_expressions`.
 
         .. versionadded:: 2.0
         """
@@ -640,6 +668,38 @@ class Permissions(BaseFlags):
         """
         return 1 << 40
 
+    @flag_value
+    def use_soundboard(self) -> int:
+        """:class:`bool`: Returns ``True`` if a user can use the soundboard.
+
+        .. versionadded:: 2.3
+        """
+        return 1 << 42
+
+    @flag_value
+    def create_expressions(self) -> int:
+        """:class:`bool`: Returns ``True`` if a user can create emojis, stickers, and soundboard sounds.
+
+        .. versionadded:: 2.3
+        """
+        return 1 << 43
+
+    @flag_value
+    def use_external_sounds(self) -> int:
+        """:class:`bool`: Returns ``True`` if a user can use sounds from other guilds.
+
+        .. versionadded:: 2.3
+        """
+        return 1 << 45
+
+    @flag_value
+    def send_voice_messages(self) -> int:
+        """:class:`bool`: Returns ``True`` if a user can send voice messages.
+
+        .. versionadded:: 2.3
+        """
+        return 1 << 46
+
 
 def _augment_from_permissions(cls):
     cls.VALID_NAMES = set(Permissions.VALID_FLAGS)
@@ -741,6 +801,7 @@ class PermissionOverwrite:
         manage_roles: Optional[bool]
         manage_permissions: Optional[bool]
         manage_webhooks: Optional[bool]
+        manage_expressions: Optional[bool]
         manage_emojis: Optional[bool]
         manage_emojis_and_stickers: Optional[bool]
         use_application_commands: Optional[bool]
@@ -754,6 +815,10 @@ class PermissionOverwrite:
         use_external_stickers: Optional[bool]
         use_embedded_activities: Optional[bool]
         moderate_members: Optional[bool]
+        use_soundboard: Optional[bool]
+        use_external_sounds: Optional[bool]
+        send_voice_messages: Optional[bool]
+        create_expressions: Optional[bool]
 
     def __init__(self, **kwargs: Optional[bool]):
         self._values: Dict[str, Optional[bool]] = {}
