@@ -137,9 +137,10 @@ class TextInput(Item[V]):
     @custom_id.setter
     def custom_id(self, value: str) -> None:
         if not isinstance(value, str):
-            raise TypeError('custom_id must be None or str')
+            raise TypeError('custom_id must be a str')
 
         self._underlying.custom_id = value
+        self._provided_custom_id = True
 
     @property
     def width(self) -> int:
